summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--audio/A2dpAudioInterface.cpp4
-rw-r--r--audio/AudioDumpInterface.cpp2
-rw-r--r--audio/AudioHardwareGeneric.cpp4
-rw-r--r--audio/AudioPolicyManagerBase.cpp24
-rw-r--r--audio/audio_hw_hal.cpp8
-rw-r--r--power/power.c2
-rw-r--r--wifi/wifi.c46
7 files changed, 45 insertions, 45 deletions
diff --git a/audio/A2dpAudioInterface.cpp b/audio/A2dpAudioInterface.cpp
index 4c7351d..cc435bd 100644
--- a/audio/A2dpAudioInterface.cpp
+++ b/audio/A2dpAudioInterface.cpp
@@ -301,7 +301,7 @@ ssize_t A2dpAudioInterface::A2dpAudioStreamOut::write(const void* buffer, size_t
while (remaining > 0 && retries) {
status = a2dp_write(mData, buffer, remaining);
if (status < 0) {
- LOGE("a2dp_write failed err: %d\n", status);
+ ALOGE("a2dp_write failed err: %d\n", status);
goto Error;
}
if (status == 0) {
@@ -338,7 +338,7 @@ status_t A2dpAudioInterface::A2dpAudioStreamOut::init()
if (!mData) {
status_t status = a2dp_init(44100, 2, &mData);
if (status < 0) {
- LOGE("a2dp_init failed err: %d\n", status);
+ ALOGE("a2dp_init failed err: %d\n", status);
mData = NULL;
return status;
}
diff --git a/audio/AudioDumpInterface.cpp b/audio/AudioDumpInterface.cpp
index 9f07ba3..62fdbd6 100644
--- a/audio/AudioDumpInterface.cpp
+++ b/audio/AudioDumpInterface.cpp
@@ -35,7 +35,7 @@ AudioDumpInterface::AudioDumpInterface(AudioHardwareInterface* hw)
: mPolicyCommands(String8("")), mFileName(String8(""))
{
if(hw == 0) {
- LOGE("Dump construct hw = 0");
+ ALOGE("Dump construct hw = 0");
}
mFinalInterface = hw;
ALOGV("Constructor %p, mFinalInterface %p", this, mFinalInterface);
diff --git a/audio/AudioHardwareGeneric.cpp b/audio/AudioHardwareGeneric.cpp
index 824b36b..a2b00f8 100644
--- a/audio/AudioHardwareGeneric.cpp
+++ b/audio/AudioHardwareGeneric.cpp
@@ -323,7 +323,7 @@ status_t AudioStreamInGeneric::set(
if ((*pFormat != format()) ||
(*pChannels != channels()) ||
(*pRate != sampleRate())) {
- LOGE("Error opening input channel");
+ ALOGE("Error opening input channel");
*pFormat = format();
*pChannels = channels();
*pRate = sampleRate();
@@ -344,7 +344,7 @@ ssize_t AudioStreamInGeneric::read(void* buffer, ssize_t bytes)
{
AutoMutex lock(mLock);
if (mFd < 0) {
- LOGE("Attempt to read from unopened device");
+ ALOGE("Attempt to read from unopened device");
return NO_INIT;
}
return ::read(mFd, buffer, bytes);
diff --git a/audio/audio_hw_hal.cpp b/audio/audio_hw_hal.cpp
index e6805c5..6810c87 100644
--- a/audio/audio_hw_hal.cpp
+++ b/audio/audio_hw_hal.cpp
@@ -65,7 +65,7 @@ static int out_set_sample_rate(struct audio_stream *stream, uint32_t rate)
struct legacy_stream_out *out =
reinterpret_cast<struct legacy_stream_out *>(stream);
- LOGE("(%s:%d) %s: Implement me!", __FILE__, __LINE__, __func__);
+ ALOGE("(%s:%d) %s: Implement me!", __FILE__, __LINE__, __func__);
/* TODO: implement this */
return 0;
}
@@ -95,7 +95,7 @@ static int out_set_format(struct audio_stream *stream, int format)
{
struct legacy_stream_out *out =
reinterpret_cast<struct legacy_stream_out *>(stream);
- LOGE("(%s:%d) %s: Implement me!", __FILE__, __LINE__, __func__);
+ ALOGE("(%s:%d) %s: Implement me!", __FILE__, __LINE__, __func__);
/* TODO: implement me */
return 0;
}
@@ -185,7 +185,7 @@ static int in_set_sample_rate(struct audio_stream *stream, uint32_t rate)
struct legacy_stream_in *in =
reinterpret_cast<struct legacy_stream_in *>(stream);
- LOGE("(%s:%d) %s: Implement me!", __FILE__, __LINE__, __func__);
+ ALOGE("(%s:%d) %s: Implement me!", __FILE__, __LINE__, __func__);
/* TODO: implement this */
return 0;
}
@@ -215,7 +215,7 @@ static int in_set_format(struct audio_stream *stream, int format)
{
struct legacy_stream_in *in =
reinterpret_cast<struct legacy_stream_in *>(stream);
- LOGE("(%s:%d) %s: Implement me!", __FILE__, __LINE__, __func__);
+ ALOGE("(%s:%d) %s: Implement me!", __FILE__, __LINE__, __func__);
/* TODO: implement me */
return 0;
}
diff --git a/power/power.c b/power/power.c
index bfdaf5a..8b448b4 100644
--- a/power/power.c
+++ b/power/power.c
@@ -185,7 +185,7 @@ set_screen_state(int on)
len = write(g_fds[REQUEST_STATE], buf, len);
if(len < 0) {
failure:
- LOGE("Failed setting last user activity: g_error=%d\n", g_error);
+ ALOGE("Failed setting last user activity: g_error=%d\n", g_error);
}
return 0;
}
diff --git a/wifi/wifi.c b/wifi/wifi.c
index 7cb2db3..d3dcb55 100644
--- a/wifi/wifi.c
+++ b/wifi/wifi.c
@@ -290,19 +290,19 @@ int ensure_entropy_file_exists()
if ((ret == 0) || (errno == EACCES)) {
if ((ret != 0) &&
(chmod(SUPP_ENTROPY_FILE, S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP) != 0)) {
- LOGE("Cannot set RW to \"%s\": %s", SUPP_ENTROPY_FILE, strerror(errno));
+ ALOGE("Cannot set RW to \"%s\": %s", SUPP_ENTROPY_FILE, strerror(errno));
return -1;
}
return 0;
}
destfd = open(SUPP_ENTROPY_FILE, O_CREAT|O_RDWR, 0660);
if (destfd < 0) {
- LOGE("Cannot create \"%s\": %s", SUPP_ENTROPY_FILE, strerror(errno));
+ ALOGE("Cannot create \"%s\": %s", SUPP_ENTROPY_FILE, strerror(errno));
return -1;
}
if (write(destfd, dummy_key, sizeof(dummy_key)) != sizeof(dummy_key)) {
- LOGE("Error writing \"%s\": %s", SUPP_ENTROPY_FILE, strerror(errno));
+ ALOGE("Error writing \"%s\": %s", SUPP_ENTROPY_FILE, strerror(errno));
close(destfd);
return -1;
}
@@ -310,14 +310,14 @@ int ensure_entropy_file_exists()
/* chmod is needed because open() didn't set permisions properly */
if (chmod(SUPP_ENTROPY_FILE, 0660) < 0) {
- LOGE("Error changing permissions of %s to 0660: %s",
+ ALOGE("Error changing permissions of %s to 0660: %s",
SUPP_ENTROPY_FILE, strerror(errno));
unlink(SUPP_ENTROPY_FILE);
return -1;
}
if (chown(SUPP_ENTROPY_FILE, AID_SYSTEM, AID_WIFI) < 0) {
- LOGE("Error changing group ownership of %s to %d: %s",
+ ALOGE("Error changing group ownership of %s to %d: %s",
SUPP_ENTROPY_FILE, AID_WIFI, strerror(errno));
unlink(SUPP_ENTROPY_FILE);
return -1;
@@ -342,14 +342,14 @@ int update_ctrl_interface(const char *config_file) {
return 0;
srcfd = open(config_file, O_RDONLY);
if (srcfd < 0) {
- LOGE("Cannot open \"%s\": %s", config_file, strerror(errno));
+ ALOGE("Cannot open \"%s\": %s", config_file, strerror(errno));
free(pbuf);
return 0;
}
nread = read(srcfd, pbuf, sb.st_size);
close(srcfd);
if (nread < 0) {
- LOGE("Cannot read \"%s\": %s", config_file, strerror(errno));
+ ALOGE("Cannot read \"%s\": %s", config_file, strerror(errno));
free(pbuf);
return 0;
}
@@ -365,7 +365,7 @@ int update_ctrl_interface(const char *config_file) {
int mlen = strlen(ifc);
int nwrite;
if (strncmp(ifc, iptr, mlen) != 0) {
- LOGE("ctrl_interface != %s", ifc);
+ ALOGE("ctrl_interface != %s", ifc);
while (((ilen + (iptr - pbuf)) < nread) && (iptr[ilen] != '\n'))
ilen++;
mlen = ((ilen >= mlen) ? ilen : mlen) + 1;
@@ -374,7 +374,7 @@ int update_ctrl_interface(const char *config_file) {
memcpy(iptr, ifc, strlen(ifc));
destfd = open(config_file, O_RDWR, 0660);
if (destfd < 0) {
- LOGE("Cannot update \"%s\": %s", config_file, strerror(errno));
+ ALOGE("Cannot update \"%s\": %s", config_file, strerror(errno));
free(pbuf);
return -1;
}
@@ -398,7 +398,7 @@ int ensure_config_file_exists(const char *config_file)
if ((ret == 0) || (errno == EACCES)) {
if ((ret != 0) &&
(chmod(config_file, S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP) != 0)) {
- LOGE("Cannot set RW to \"%s\": %s", config_file, strerror(errno));
+ ALOGE("Cannot set RW to \"%s\": %s", config_file, strerror(errno));
return -1;
}
/* return if filesize is at least 10 bytes */
@@ -406,26 +406,26 @@ int ensure_config_file_exists(const char *config_file)
return update_ctrl_interface(config_file);
}
} else if (errno != ENOENT) {
- LOGE("Cannot access \"%s\": %s", config_file, strerror(errno));
+ ALOGE("Cannot access \"%s\": %s", config_file, strerror(errno));
return -1;
}
srcfd = open(SUPP_CONFIG_TEMPLATE, O_RDONLY);
if (srcfd < 0) {
- LOGE("Cannot open \"%s\": %s", SUPP_CONFIG_TEMPLATE, strerror(errno));
+ ALOGE("Cannot open \"%s\": %s", SUPP_CONFIG_TEMPLATE, strerror(errno));
return -1;
}
destfd = open(config_file, O_CREAT|O_RDWR, 0660);
if (destfd < 0) {
close(srcfd);
- LOGE("Cannot create \"%s\": %s", config_file, strerror(errno));
+ ALOGE("Cannot create \"%s\": %s", config_file, strerror(errno));
return -1;
}
while ((nread = read(srcfd, buf, sizeof(buf))) != 0) {
if (nread < 0) {
- LOGE("Error reading \"%s\": %s", SUPP_CONFIG_TEMPLATE, strerror(errno));
+ ALOGE("Error reading \"%s\": %s", SUPP_CONFIG_TEMPLATE, strerror(errno));
close(srcfd);
close(destfd);
unlink(config_file);
@@ -439,14 +439,14 @@ int ensure_config_file_exists(const char *config_file)
/* chmod is needed because open() didn't set permisions properly */
if (chmod(config_file, 0660) < 0) {
- LOGE("Error changing permissions of %s to 0660: %s",
+ ALOGE("Error changing permissions of %s to 0660: %s",
config_file, strerror(errno));
unlink(config_file);
return -1;
}
if (chown(config_file, AID_SYSTEM, AID_WIFI) < 0) {
- LOGE("Error changing group ownership of %s to %d: %s",
+ ALOGE("Error changing group ownership of %s to %d: %s",
config_file, AID_WIFI, strerror(errno));
unlink(config_file);
return -1;
@@ -511,12 +511,12 @@ int wifi_start_supplicant_common(const char *config_file)
/* Before starting the daemon, make sure its config file exists */
if (ensure_config_file_exists(config_file) < 0) {
- LOGE("Wi-Fi will not be enabled");
+ ALOGE("Wi-Fi will not be enabled");
return -1;
}
if (ensure_entropy_file_exists() < 0) {
- LOGE("Wi-Fi entropy file was not created");
+ ALOGE("Wi-Fi entropy file was not created");
}
/* Clear out any stale socket files that might be left over. */
@@ -612,13 +612,13 @@ int wifi_connect_on_socket_path(int index, const char *path)
/* Make sure supplicant is running */
if (!property_get(SUPP_PROP_NAME, supp_status, NULL)
|| strcmp(supp_status, "running") != 0) {
- LOGE("Supplicant not running, cannot connect");
+ ALOGE("Supplicant not running, cannot connect");
return -1;
}
ctrl_conn[index] = wpa_ctrl_open(path);
if (ctrl_conn[index] == NULL) {
- LOGE("Unable to open connection to supplicant on \"%s\": %s",
+ ALOGE("Unable to open connection to supplicant on \"%s\": %s",
path, strerror(errno));
return -1;
}
@@ -699,7 +699,7 @@ int wifi_ctrl_recv(int index, char *reply, size_t *reply_len)
rfds[1].events |= POLLIN;
res = poll(rfds, 2, -1);
if (res < 0) {
- LOGE("Error poll = %d", res);
+ ALOGE("Error poll = %d", res);
return res;
}
if (rfds[0].revents & POLLIN) {
@@ -851,12 +851,12 @@ int wifi_change_fw_path(const char *fwpath)
return ret;
fd = open(WIFI_DRIVER_FW_PATH_PARAM, O_WRONLY);
if (fd < 0) {
- LOGE("Failed to open wlan fw path param (%s)", strerror(errno));
+ ALOGE("Failed to open wlan fw path param (%s)", strerror(errno));
return -1;
}
len = strlen(fwpath) + 1;
if (write(fd, fwpath, len) != len) {
- LOGE("Failed to write wlan fw path param (%s)", strerror(errno));
+ ALOGE("Failed to write wlan fw path param (%s)", strerror(errno));
ret = -1;
}
close(fd);
diff --git a/audio/AudioPolicyManagerBase.cpp b/audio/AudioPolicyManagerBase.cpp
index 142bfd2..45df7fe 100644
--- a/audio/AudioPolicyManagerBase.cpp
+++ b/audio/AudioPolicyManagerBase.cpp
@@ -39,7 +39,7 @@ status_t AudioPolicyManagerBase::setDeviceConnectionState(AudioSystem::audio_dev
if (AudioSystem::popCount(device) != 1) return BAD_VALUE;
if (strlen(device_address) >= MAX_DEVICE_ADDRESS_LEN) {
- LOGE("setDeviceConnectionState() invalid address: %s", device_address);
+ ALOGE("setDeviceConnectionState() invalid address: %s", device_address);
return BAD_VALUE;
}
@@ -48,7 +48,7 @@ status_t AudioPolicyManagerBase::setDeviceConnectionState(AudioSystem::audio_dev
#ifndef WITH_A2DP
if (AudioSystem::isA2dpDevice(device)) {
- LOGE("setDeviceConnectionState() invalid device: %x", device);
+ ALOGE("setDeviceConnectionState() invalid device: %x", device);
return BAD_VALUE;
}
#endif
@@ -114,7 +114,7 @@ status_t AudioPolicyManagerBase::setDeviceConnectionState(AudioSystem::audio_dev
} break;
default:
- LOGE("setDeviceConnectionState() invalid state: %x", state);
+ ALOGE("setDeviceConnectionState() invalid state: %x", state);
return BAD_VALUE;
}
@@ -166,7 +166,7 @@ status_t AudioPolicyManagerBase::setDeviceConnectionState(AudioSystem::audio_dev
} break;
default:
- LOGE("setDeviceConnectionState() invalid state: %x", state);
+ ALOGE("setDeviceConnectionState() invalid state: %x", state);
return BAD_VALUE;
}
@@ -1098,7 +1098,7 @@ AudioPolicyManagerBase::AudioPolicyManagerBase(AudioPolicyClientInterface *clien
outputDesc->mFlags);
if (mHardwareOutput == 0) {
- LOGE("Failed to initialize hardware output stream, samplingRate: %d, format %d, channels %d",
+ ALOGE("Failed to initialize hardware output stream, samplingRate: %d, format %d, channels %d",
outputDesc->mSamplingRate, outputDesc->mFormat, outputDesc->mChannels);
} else {
addOutput(mHardwareOutput, outputDesc);
@@ -1263,7 +1263,7 @@ bool AudioPolicyManagerBase::threadLoop()
&outputDesc->mLatency,
outputDesc->mFlags);
if (mHardwareOutput == 0) {
- LOGE("Failed to reopen hardware output stream, samplingRate: %d, format %d, channels %d",
+ ALOGE("Failed to reopen hardware output stream, samplingRate: %d, format %d, channels %d",
outputDesc->mSamplingRate, outputDesc->mFormat, outputDesc->mChannels);
} else {
AudioParameter outputCmd = AudioParameter();
@@ -1595,7 +1595,7 @@ uint32_t AudioPolicyManagerBase::getStrategyForStream(AudioSystem::stream_type s
uint32_t AudioPolicyManagerBase::getDevicesForStream(AudioSystem::stream_type stream) {
uint32_t devices;
// By checking the range of stream before calling getStrategy, we avoid
// getStrategy's behavior for invalid streams. getStrategy would do a LOGE
// and then return STRATEGY_MEDIA, but we want to return the empty set.
if (stream < (AudioSystem::stream_type) 0 || stream >= AudioSystem::NUM_STREAM_TYPES) {
devices = 0;
@@ -1620,7 +1620,7 @@ AudioPolicyManagerBase::routing_strategy AudioPolicyManagerBase::getStrategy(
case AudioSystem::DTMF:
return STRATEGY_DTMF;
default:
- LOGE("unknown stream type");
+ ALOGE("unknown stream type");
case AudioSystem::SYSTEM:
// NOTE: SYSTEM stream uses MEDIA strategy because muting music and switching outputs
// while key clicks are played produces a poor result
@@ -1689,7 +1689,7 @@ uint32_t AudioPolicyManagerBase::getDeviceForStrategy(routing_strategy strategy,
if (device) break;
device = mAvailableOutputDevices & AudioSystem::DEVICE_OUT_EARPIECE;
if (device == 0) {
- LOGE("getDeviceForStrategy() earpiece device not found");
+ ALOGE("getDeviceForStrategy() earpiece device not found");
}
break;
@@ -1710,7 +1710,7 @@ uint32_t AudioPolicyManagerBase::getDeviceForStrategy(routing_strategy strategy,
if (device) break;
device = mAvailableOutputDevices & AudioSystem::DEVICE_OUT_SPEAKER;
if (device == 0) {
- LOGE("getDeviceForStrategy() speaker device not found");
+ ALOGE("getDeviceForStrategy() speaker device not found");
}
break;
}
@@ -1732,7 +1732,7 @@ uint32_t AudioPolicyManagerBase::getDeviceForStrategy(routing_strategy strategy,
device = mAvailableOutputDevices & AudioSystem::DEVICE_OUT_SPEAKER;
if (device == 0) {
- LOGE("getDeviceForStrategy() speaker device not found");
+ ALOGE("getDeviceForStrategy() speaker device not found");
}
// The second device used for sonification is the same as the device used by media strategy
// FALL THROUGH
@@ -1773,7 +1773,7 @@ uint32_t AudioPolicyManagerBase::getDeviceForStrategy(routing_strategy strategy,
// STRATEGY_ENFORCED_AUDIBLE, 0 otherwise
device |= device2;
if (device == 0) {
- LOGE("getDeviceForStrategy() speaker device not found");
+ ALOGE("getDeviceForStrategy() speaker device not found");
}
} break;
@@ -1595,7 +1595,7 @@ uint32_t AudioPolicyManagerBase::getStrategyForStream(AudioSystem::stream_type s
uint32_t devices;
// By checking the range of stream before calling getStrategy, we avoid
- // getStrategy's behavior for invalid streams. getStrategy would do a LOGE
+ // getStrategy's behavior for invalid streams. getStrategy would do a ALOGE
// and then return STRATEGY_MEDIA, but we want to return the empty set.
if (stream < (AudioSystem::stream_type) 0 || stream >= AudioSystem::NUM_STREAM_TYPES) {